@@ -13,6 +13,10 @@ from hdmf.backends.io import HDMFIO
 from hdmf.backends.hdf5 import HDF5IO as _HDF5IO
 from hdmf.build import BuildManager, TypeMap
 import hdmf.common
+from hdmf.common import load_type_config as hdmf_load_type_config
+from hdmf.common import get_loaded_type_config as hdmf_get_loaded_type_config
+from hdmf.common import unload_type_config as hdmf_unload_type_config
+
 
 CORE_NAMESPACE = 'core'
 
@@ -20,6 +24,33 @@ from .spec import NWBDatasetSpec, NWBGroupSpec, NWBNamespace  # noqa E402
 from .validate import validate  # noqa: F401, E402
 
 
+@docval({'name': 'config_path', 'type': str, 'doc': 'Path to the configuration file.'},
+        {'name': 'type_map', 'type': TypeMap, 'doc': 'The TypeMap.', 'default': None},
+        is_method=False)
+def load_type_config(**kwargs):
+    """
+    This method will either load the default config or the config provided by the path.
+    """
+    config_path = kwargs['config_path']
+    type_map = kwargs['type_map'] or get_type_map()
+
+    hdmf_load_type_config(config_path=config_path, type_map=type_map)
+
+@docval({'name': 'type_map', 'type': TypeMap, 'doc': 'The TypeMap.', 'default': None},
+        is_method=False)
+def get_loaded_type_config(**kwargs):
+    type_map = kwargs['type_map'] or get_type_map()
+    return hdmf_get_loaded_type_config(type_map=type_map)
+
+@docval({'name': 'type_map', 'type': TypeMap, 'doc': 'The TypeMap.', 'default': None},
+        is_method=False)
+def unload_type_config(**kwargs):
+    """
+    Remove validation.
+    """
+    type_map = kwargs['type_map'] or get_type_map()
+    hdmf_unload_type_config(type_map=type_map)
+
 def __get_resources():
     try:
         from importlib.resources import files
@@ -148,6 +179,37 @@ def register_class(**kwargs):
         _dec(container_cls)
 
 
+@docval({'name': 'h5py_file', 'type': h5py.File, 'doc': 'An NWB file'}, rtype=tuple,
+        is_method=False,)
+def get_nwbfile_version(**kwargs):
+    """
+    Get the NWB version of the file if it is an NWB file.
+
+    :Returns: Tuple consisting of: 1) the
+        original version string as stored in the file and 2) a tuple with the parsed components of the version string,
+        consisting of integers and strings, e.g., (2, 5, 1, beta). (None, None) will be returned if the file is not a
+        valid NWB file or the nwb_version is missing, e.g., in the case when no data has been written to the file yet.
+    """
+    # Get the version string for the NWB file
+    h5py_file = getargs('h5py_file', kwargs)
+    try:
+        nwb_version_string = h5py_file.attrs['nwb_version']
+    #  KeyError occurs  when the file is empty (e.g., when creating a new file nothing has been written)
+    #  or when the HDF5 file is not a valid NWB file
+    except KeyError:
+        return None, None
+    # Other system may have written nwb_version as a fixed-length string, resulting in a numpy.bytes_ object
+    # on read, rather than a variable-length string. To address this, decode the bytes if necessary.
+    if not isinstance(nwb_version_string, str):
+        nwb_version_string = nwb_version_string.decode()
+
+    # Parse the version string
+    nwb_version_parts = nwb_version_string.replace("-", ".").replace("_", ".").split(".")
+    nwb_version = tuple([int(i) if i.isnumeric() else i
+                         for i in nwb_version_parts])
+    return nwb_version_string, nwb_version
+
+
 # a function to register an object mapper for a container class
 @docval({"name": "container_cls", "type": type,
          "doc": "the Container class for which the given ObjectMapper class gets used"},
@@ -201,39 +263,50 @@ def get_class(**kwargs):
 
 class NWBHDF5IO(_HDF5IO):
 
+    @staticmethod
+    def can_read(path: str):
+        """Determine whether a given path is readable by this class"""
+        if not os.path.isfile(path):  # path is file that exists
+            return False
+        try:
+            with h5py.File(path, "r") as file:   # path is HDF5 file
+                version_info = get_nwbfile_version(file)
+                if version_info[0] is None:
+                    warn("Cannot read because missing NWB version in the HDF5 file. The file is not a valid NWB file.")
+                    return False
+                elif version_info[1][0] < 2:    # Major versions of NWB < 2 not supported
+                    warn("Cannot read because PyNWB supports NWB files version 2 and above.")
+                    return False
+                else:
+                    return True
+        except IOError:
+            return False
+
     @docval({'name': 'path', 'type': (str, Path), 'doc': 'the path to the HDF5 file', 'default': None},
             {'name': 'mode', 'type': str,
              'doc': 'the mode to open the HDF5 file with, one of ("w", "r", "r+", "a", "w-", "x")',
              'default': 'r'},
             {'name': 'load_namespaces', 'type': bool,
-             'doc': 'whether or not to load cached namespaces from given path - not applicable in write mode',
-             'default': False},
+             'doc': ('whether or not to load cached namespaces from given path - not applicable in write mode '
+                     'or when `manager` is not None or when `extensions` is not None'),
+             'default': True},
             {'name': 'manager', 'type': BuildManager, 'doc': 'the BuildManager to use for I/O', 'default': None},
             {'name': 'extensions', 'type': (str, TypeMap, list),
              'doc': 'a path to a namespace, a TypeMap, or a list consisting paths to namespaces and TypeMaps',
              'default': None},
-            {'name': 'file', 'type': [h5py.File, 'S3File'], 'doc': 'a pre-existing h5py.File object', 'default': None},
-            {'name': 'comm', 'type': "Intracomm", 'doc': 'the MPI communicator to use for parallel I/O',
-             'default': None},
-            {'name': 'driver', 'type': str, 'doc': 'driver for h5py to use when opening HDF5 file', 'default': None},
-            {'name': 'herd_path', 'type': str, 'doc': 'The path to the HERD',
-             'default': None},)
+            *get_docval(_HDF5IO.__init__, "file", "comm", "driver", "aws_region", "herd_path"),)
     def __init__(self, **kwargs):
-        path, mode, manager, extensions, load_namespaces, file_obj, comm, driver, herd_path =\
+        path, mode, manager, extensions, load_namespaces, file_obj, comm, driver, aws_region, herd_path =\
             popargs('path', 'mode', 'manager', 'extensions', 'load_namespaces',
-                    'file', 'comm', 'driver', 'herd_path', kwargs)
+                    'file', 'comm', 'driver', 'aws_region', 'herd_path', kwargs)
         # Define the BuildManager to use
-        if load_namespaces:
-            if manager is not None:
-                warn("loading namespaces from file - ignoring 'manager'")
-            if extensions is not None:
-                warn("loading namespaces from file - ignoring 'extensions' argument")
-            # namespaces are not loaded when creating an NWBHDF5IO object in write mode
-            if 'w' in mode or mode == 'x':
-                raise ValueError("cannot load namespaces from file when writing to it")
+        io_modes_that_create_file = ['w', 'w-', 'x']
+        if mode in io_modes_that_create_file or manager is not None or extensions is not None:
+            load_namespaces = False
 
+        if load_namespaces:
             tm = get_type_map()
-            super().load_namespaces(tm, path, file=file_obj, driver=driver)
+            super().load_namespaces(tm, path, file=file_obj, driver=driver, aws_region=aws_region)
             manager = BuildManager(tm)
 
             # XXX: Leaving this here in case we want to revert to this strategy for
@@ -251,7 +324,7 @@ class NWBHDF5IO(_HDF5IO):
                 manager = get_manager()
         # Open the file
         super().__init__(path, manager=manager, mode=mode, file=file_obj, comm=comm,
-                         driver=driver, herd_path=herd_path)
+                         driver=driver, aws_region=aws_region, herd_path=herd_path)
 
     @property
     def nwb_version(self):
@@ -263,23 +336,7 @@ class NWBHDF5IO(_HDF5IO):
                   and strings, e.g., (2, 5, 1, beta). (None, None) will be returned if the nwb_version
                   is missing, e.g., in the case when no data has been written to the file yet.
         """
-        # Get the version string for the NWB file
-        try:
-            nwb_version_string = self._file.attrs['nwb_version']
-        #  KeyError occurs  when the file is empty (e.g., when creating a new file nothing has been written)
-        #  or when the HDF5 file is not a valid NWB file
-        except KeyError:
-            return None, None
-        # Other system may have written nwb_version as a fixed-length string, resulting in a numpy.bytes_ object
-        # on read, rather than a variable-length string. To address this, decode the bytes if necessary.
-        if not isinstance(nwb_version_string, str):
-            nwb_version_string = nwb_version_string.decode()
-
-        # Parse the version string
-        nwb_version_parts = nwb_version_string.replace("-", ".").replace("_", ".").split(".")
-        nwb_version = tuple([int(i) if i.isnumeric() else i
-                             for i in nwb_version_parts])
-        return nwb_version_string, nwb_version
+        return get_nwbfile_version(self._file)
 
     @docval(*get_docval(_HDF5IO.read),
             {'name': 'skip_version_check', 'type': bool, 'doc': 'skip checking of NWB version', 'default': False})
@@ -309,8 +366,11 @@ class NWBHDF5IO(_HDF5IO):
             {'name': 'nwbfile', 'type': 'NWBFile',
              'doc': 'the NWBFile object to export. If None, then the entire contents of src_io will be exported',
              'default': None},
-            {'name': 'write_args', 'type': dict, 'doc': 'arguments to pass to :py:meth:`write_builder`',
-             'default': None})
+            {'name': 'write_args', 'type': dict,
+             'doc': 'arguments to pass to :py:meth:`~hdmf.backends.io.HDMFIO.write_builder`',
+             'default': None},
+            {'name': 'cache_spec', 'type': bool, 'doc': 'whether to cache the specification to file',
+             'default': True})
     def export(self, **kwargs):
         """
         Export an NWB file to a new NWB file using the HDF5 backend.
@@ -363,13 +423,19 @@ from . import image  # noqa: F401,E402
 from . import misc  # noqa: F401,E402
 from . import ogen  # noqa: F401,E402
 from . import ophys  # noqa: F401,E402
-from . import retinotopy  # noqa: F401,E402
 from . import legacy  # noqa: F401,E402
 from hdmf.data_utils import DataChunkIterator  # noqa: F401,E402
 from hdmf.backends.hdf5 import H5DataIO  # noqa: F401,E402
 
-from . import _version    # noqa: F401,E402
-__version__ = _version.get_versions()['version']
+try:
+    # see https://effigies.gitlab.io/posts/python-packaging-2023/
+    from ._version import __version__
+except ImportError:  # pragma: no cover
+    # this is a relatively slower method for getting the version string
+    from importlib.metadata import version  # noqa: E402
+
+    __version__ = version("pynwb")
+    del version
 
 from ._due import due, BibTeX  # noqa: E402
 due.cite(
