@@ -1,35 +1,40 @@
+import warnings
 from collections.abc import Iterable
 
-from hdmf.utils import docval, getargs, popargs, call_docval_func, get_docval
+from hdmf.common import DynamicTableRegion
 from hdmf.data_utils import DataChunkIterator, assertEqualShape
+from hdmf.utils import docval, popargs, get_docval, popargs_to_dict, get_data_shape
 
 from . import register_class, CORE_NAMESPACE
 from .base import TimeSeries
 from .core import NWBContainer, NWBDataInterface, MultiContainerInterface
-from hdmf.common import DynamicTableRegion
 from .device import Device
 
 
 @register_class('ElectrodeGroup', CORE_NAMESPACE)
 class ElectrodeGroup(NWBContainer):
-    """
-    """
+    """Defines a related group of electrodes."""
 
     __nwbfields__ = ('name',
                      'description',
                      'location',
-                     'device')
+                     'device',
+                     'position')
 
-    @docval({'name': 'name', 'type': str, 'doc': 'the name of this electrode'},
+    @docval({'name': 'name', 'type': str, 'doc': 'the name of this electrode group'},
             {'name': 'description', 'type': str, 'doc': 'description of this electrode group'},
             {'name': 'location', 'type': str, 'doc': 'description of location of this electrode group'},
-            {'name': 'device', 'type': Device, 'doc': 'the device that was used to record from this electrode group'})
+            {'name': 'device', 'type': Device, 'doc': 'the device that was used to record from this electrode group'},
+            {'name': 'position', 'type': 'array_data',
+             'doc': 'stereotaxic position of this electrode group (x, y, z)', 'default': None})
     def __init__(self, **kwargs):
-        call_docval_func(super(ElectrodeGroup, self).__init__, kwargs)
-        description, location, device = popargs("description", "location", "device", kwargs)
-        self.description = description
-        self.location = location
-        self.device = device
+        args_to_set = popargs_to_dict(('description', 'location', 'device', 'position'), kwargs)
+        super().__init__(**kwargs)
+        if args_to_set['position'] and len(args_to_set['position']) != 3:
+            raise ValueError('ElectrodeGroup position argument must have three elements: x, y, z, but received: %s'
+                             % str(args_to_set['position']))
+        for key, val in args_to_set.items():
+            setattr(self, key, val)
 
 
 @register_class('ElectricalSeries', CORE_NAMESPACE)
@@ -42,12 +47,14 @@ class ElectricalSeries(TimeSeries):
 
     __nwbfields__ = ({'name': 'electrodes', 'required_name': 'electrodes',
                       'doc': 'the electrodes that generated this electrical series', 'child': True},
-                     'channel_conversion')
+                     'channel_conversion',
+                     'filtering')
 
     @docval(*get_docval(TimeSeries.__init__, 'name'),  # required
             {'name': 'data', 'type': ('array_data', 'data', TimeSeries),  # required
              'shape': ((None, ), (None, None), (None, None, None)),
-             'doc': 'The data this TimeSeries dataset stores. Can also store binary data e.g. image frames'},
+             'doc': ('The data values. Can be 1D or 2D. The first dimension must be time. The second dimension '
+                     'represents electrodes/channels.')},
             {'name': 'electrodes', 'type': DynamicTableRegion,  # required
              'doc': 'the table region corresponding to the electrodes from which this series was recorded'},
             {'name': 'channel_conversion', 'type': ('array_data', 'data'), 'shape': (None,), 'doc':
@@ -58,13 +65,35 @@ class ElectricalSeries(TimeSeries):
              "to support the storage of electrical recordings as native values generated by data acquisition systems. "
              "If this dataset is not present, then there is no channel-specific conversion factor, i.e. it is 1 for all"
              " channels.", 'default': None},
+            {'name': 'filtering', 'type': str, 'doc':
+             "Filtering applied to all channels of the data. For example, if this ElectricalSeries represents "
+             "high-pass-filtered data (also known as AP Band), then this value could be 'High-pass 4-pole Bessel "
+             "filter at 500 Hz'. If this ElectricalSeries represents low-pass-filtered LFP data and the type of "
+             "filter is unknown, then this value could be 'Low-pass filter at 300 Hz'. If a non-standard filter "
+             "type is used, provide as much detail about the filter properties as possible.", 'default': None},
             *get_docval(TimeSeries.__init__, 'resolution', 'conversion', 'timestamps', 'starting_time', 'rate',
-                        'comments', 'description', 'control', 'control_description'))
+                        'comments', 'description', 'control', 'control_description', 'offset'))
     def __init__(self, **kwargs):
-        name, electrodes, data, channel_conversion = popargs('name', 'electrodes', 'data', 'channel_conversion', kwargs)
-        super(ElectricalSeries, self).__init__(name, data, 'volts', **kwargs)
-        self.electrodes = electrodes
-        self.channel_conversion = channel_conversion
+        args_to_set = popargs_to_dict(('electrodes', 'channel_conversion', 'filtering'), kwargs)
+
+        data_shape = get_data_shape(kwargs['data'], strict_no_data_load=True)
+        if (
+            data_shape is not None
+            and len(data_shape) == 2
+            and data_shape[1] != len(args_to_set['electrodes'].data)
+        ):
+            if data_shape[0] == len(args_to_set['electrodes'].data):
+                warnings.warn("%s '%s': The second dimension of data does not match the length of electrodes, "
+                              "but instead the first does. Data is oriented incorrectly and should be transposed."
+                              % (self.__class__.__name__, kwargs["name"]))
+            else:
+                warnings.warn("%s '%s': The second dimension of data does not match the length of electrodes. "
+                              "Your data may be transposed." % (self.__class__.__name__, kwargs["name"]))
+
+        kwargs['unit'] = 'volts'  # fixed value
+        super().__init__(**kwargs)
+        for key, val in args_to_set.items():
+            setattr(self, key, val)
 
 
 @register_class('SpikeEventSeries', CORE_NAMESPACE)
@@ -86,18 +115,18 @@ class SpikeEventSeries(ElectricalSeries):
              'doc': 'Timestamps for samples stored in data'},
             *get_docval(ElectricalSeries.__init__, 'electrodes'),  # required
             *get_docval(ElectricalSeries.__init__, 'resolution', 'conversion', 'comments', 'description', 'control',
-                        'control_description'))
+                        'control_description', 'offset'))
     def __init__(self, **kwargs):
-        name, data, electrodes = popargs('name', 'data', 'electrodes', kwargs)
-        timestamps = getargs('timestamps', kwargs)
+        data = kwargs['data']
+        timestamps = kwargs['timestamps']
         if not (isinstance(data, TimeSeries) or isinstance(timestamps, TimeSeries)):
             if not (isinstance(data, DataChunkIterator) or isinstance(timestamps, DataChunkIterator)):
                 if len(data) != len(timestamps):
-                    raise Exception('Must provide the same number of timestamps and spike events')
+                    raise ValueError('Must provide the same number of timestamps and spike events')
             else:
                 # TODO: add check when we have DataChunkIterators
                 pass
-        super(SpikeEventSeries, self).__init__(name, data, electrodes, **kwargs)
+        super().__init__(**kwargs)
 
 
 @register_class('EventDetection', CORE_NAMESPACE)
@@ -123,14 +152,11 @@ class EventDetection(NWBDataInterface):
             {'name': 'times', 'type': ('array_data', 'data'), 'doc': 'Timestamps of events, in Seconds'},
             {'name': 'name', 'type': str, 'doc': 'the name of this container', 'default': 'EventDetection'})
     def __init__(self, **kwargs):
-        detection_method, source_electricalseries, source_idx, times = popargs(
-            'detection_method', 'source_electricalseries', 'source_idx', 'times', kwargs)
-        super(EventDetection, self).__init__(**kwargs)
-        self.detection_method = detection_method
-        self.source_electricalseries = source_electricalseries
-        self.source_idx = source_idx
-        self.times = times
-        self.unit = 'seconds'
+        args_to_set = popargs_to_dict(('detection_method', 'source_electricalseries', 'source_idx', 'times'), kwargs)
+        super().__init__(**kwargs)
+        for key, val in args_to_set.items():
+            setattr(self, key, val)
+        self.unit = 'seconds'  # fixed value
 
 
 @register_class('EventWaveform', CORE_NAMESPACE)
@@ -175,15 +201,12 @@ class Clustering(NWBDataInterface):
              'shape': (None,)},
             {'name': 'name', 'type': str, 'doc': 'the name of this container', 'default': 'Clustering'})
     def __init__(self, **kwargs):
-        import warnings
         warnings.warn("use pynwb.misc.Units or NWBFile.units instead", DeprecationWarning)
-        description, num, peak_over_rms, times = popargs(
-            'description', 'num', 'peak_over_rms', 'times', kwargs)
-        super(Clustering, self).__init__(**kwargs)
-        self.description = description
-        self.num = num
-        self.peak_over_rms = list(peak_over_rms)
-        self.times = times
+        args_to_set = popargs_to_dict(('description', 'num', 'peak_over_rms', 'times'), kwargs)
+        super().__init__(**kwargs)
+        args_to_set['peak_over_rms'] = list(args_to_set['peak_over_rms'])
+        for key, val in args_to_set.items():
+            setattr(self, key, val)
 
 
 @register_class('ClusterWaveforms', CORE_NAMESPACE)
@@ -212,15 +235,12 @@ class ClusterWaveforms(NWBDataInterface):
              'doc': 'the standard deviations of waveforms for each cluster'},
             {'name': 'name', 'type': str, 'doc': 'the name of this container', 'default': 'ClusterWaveforms'})
     def __init__(self, **kwargs):
-        import warnings
         warnings.warn("use pynwb.misc.Units or NWBFile.units instead", DeprecationWarning)
-        clustering_interface, waveform_filtering, waveform_mean, waveform_sd = popargs(
-            'clustering_interface', 'waveform_filtering', 'waveform_mean', 'waveform_sd', kwargs)
-        super(ClusterWaveforms, self).__init__(**kwargs)
-        self.clustering_interface = clustering_interface
-        self.waveform_filtering = waveform_filtering
-        self.waveform_mean = waveform_mean
-        self.waveform_sd = waveform_sd
+        args_to_set = popargs_to_dict(('clustering_interface', 'waveform_filtering',
+                                       'waveform_mean', 'waveform_sd'), kwargs)
+        super().__init__(**kwargs)
+        for key, val in args_to_set.items():
+            setattr(self, key, val)
 
 
 @register_class('LFP', CORE_NAMESPACE)
@@ -324,7 +344,7 @@ class FeatureExtraction(NWBDataInterface):
             raise ValueError(error_msg)
 
         # Initialize the object
-        super(FeatureExtraction, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.electrodes = electrodes
         self.description = description
         self.times = list(times)
