@@ -1,4 +1,3 @@
-# flake8: noqa: F401
 from . import base as __base
 from . import behavior as __behavior
 from . import ecephys as __ecephys
@@ -9,4 +8,3 @@ from . import image as __image
 from . import misc as __misc
 from . import ogen as __ogen
 from . import ophys as __ophys
-from . import retinotopy as __retinotopy
