@@ -1,5 +1,5 @@
 
-from hdmf.build.map import ObjectMapper, TypeMap
+from hdmf.build import ObjectMapper, TypeMap
 from hdmf.build.builders import GroupBuilder
 
 
