@@ -29,8 +29,8 @@ def _validate_helper(io: HDMFIO, namespace: str = CORE_NAMESPACE) -> list:
     return validator.validate(builder)
 
 
-def _get_cached_namespaces_to_validate(
-    path: str, driver: Optional[str] = None
+def get_cached_namespaces_to_validate(
+    path: str, driver: Optional[str] = None, aws_region: Optional[str] = None,
 ) -> Tuple[List[str], BuildManager, Dict[str, str]]:
     """
     Determine the most specific namespace(s) that are cached in the given NWBFile that can be used for validation.
@@ -39,14 +39,18 @@ def _get_cached_namespaces_to_validate(
     -------
     The following example illustrates how we can use this function to validate against namespaces
     cached in a file. This is useful, e.g., when a file was created using an extension
-    >>> from pynwb import validate
-    >>> from pynwb.validate import _get_cached_namespaces_to_validate
-    >>> path = "my_nwb_file.nwb"
-    >>> validate_namespaces, manager, cached_namespaces = _get_cached_namespaces_to_validate(path)
-    >>> with NWBHDF5IO(path, "r", manager=manager) as reader:
-    >>>     errors = []
-    >>>     for ns in validate_namespaces:
-    >>>         errors += validate(io=reader, namespace=ns)
+
+    .. code-block:: python
+
+        from pynwb import validate
+        from pynwb.validate import get_cached_namespaces_to_validate
+        path = "my_nwb_file.nwb"
+        validate_namespaces, manager, cached_namespaces = get_cached_namespaces_to_validate(path)
+        with NWBHDF5IO(path, "r", manager=manager) as reader:
+            errors = []
+            for ns in validate_namespaces:
+                errors += validate(io=reader, namespace=ns)
+
     :param path: Path for the NWB file
     :return: Tuple with:
       - List of strings with the most specific namespace(s) to use for validation.
@@ -58,7 +62,12 @@ def _get_cached_namespaces_to_validate(
     catalog = NamespaceCatalog(
         group_spec_cls=NWBGroupSpec, dataset_spec_cls=NWBDatasetSpec, spec_namespace_cls=NWBNamespace
     )
-    namespace_dependencies = NWBHDF5IO.load_namespaces(namespace_catalog=catalog, path=path, driver=driver)
+    namespace_dependencies = NWBHDF5IO.load_namespaces(
+        namespace_catalog=catalog,
+        path=path,
+        driver=driver,
+        aws_region=aws_region
+    )
 
     # Determine which namespaces are the most specific (i.e. extensions) and validate against those
     candidate_namespaces = set(namespace_dependencies.keys())
@@ -120,7 +129,11 @@ def _get_cached_namespaces_to_validate(
     is_method=False,
 )
 def validate(**kwargs):
-    """Validate NWB file(s) against a namespace or its cached namespaces."""
+    """Validate NWB file(s) against a namespace or its cached namespaces.
+
+    NOTE: If an io object is provided and no namespace name is specified, then the file will be validated
+    against the core namespace, even if use_cached_namespaces is True.
+    """
     from . import NWBHDF5IO  # TODO: modularize to avoid circular import
 
     io, paths, use_cached_namespaces, namespace, verbose, driver = getargs(
@@ -140,7 +153,7 @@ def validate(**kwargs):
         io_kwargs = dict(path=path, mode="r", driver=driver)
 
         if use_cached_namespaces:
-            cached_namespaces, manager, namespace_dependencies = _get_cached_namespaces_to_validate(
+            cached_namespaces, manager, namespace_dependencies = get_cached_namespaces_to_validate(
                 path=path, driver=driver
             )
             io_kwargs.update(manager=manager)
@@ -156,6 +169,7 @@ def validate(**kwargs):
                         file=sys.stderr,
                     )
         else:
+            io_kwargs.update(load_namespaces=False)
             namespaces_to_validate = [CORE_NAMESPACE]
 
         if namespace is not None:
@@ -221,7 +235,7 @@ def validate_cli():
 
     if args.list_namespaces:
         for path in args.paths:
-            cached_namespaces, _, _ = _get_cached_namespaces_to_validate(path=path)
+            cached_namespaces, _, _ = get_cached_namespaces_to_validate(path=path)
             print("\n".join(cached_namespaces))
     else:
         validation_errors, validation_status = validate(
