@@ -3,14 +3,17 @@ import warnings
 import re
 import argparse
 import glob
+import h5py
 import inspect
 import logging
 import os.path
 import os
+import shutil
 from subprocess import run, PIPE, STDOUT
 import sys
 import traceback
 import unittest
+import importlib.util
 
 flags = {
     'pynwb': 2,
@@ -68,8 +71,11 @@ def run_test_suite(directory, description="", verbose=True):
 
 
 def _import_from_file(script):
-    import imp
-    return imp.load_source(os.path.basename(script), script)
+    modname = os.path.basename(script)
+    spec = importlib.util.spec_from_file_location(os.path.basename(script), script)
+    module = importlib.util.module_from_spec(spec)
+    sys.modules[modname] = module
+    spec.loader.exec_module(module)
 
 
 warning_re = re.compile("Parent module '[a-zA-Z0-9]+' not found while handling absolute import")
@@ -131,6 +137,11 @@ def __run_example_tests_helper(examples_scripts):
                         ws.append(w)
             for w in ws:
                 warnings.showwarning(w.message, w.category, w.filename, w.lineno, w.line)
+        except (ImportError, ValueError, ModuleNotFoundError) as e:
+            if "linkml" in str(e):
+                pass  # this is OK because linkml is not always installed
+            else:
+                raise e
         except Exception:
             print(traceback.format_exc())
             FAILURES += 1
@@ -142,7 +153,11 @@ def validate_nwbs():
     logging.info('running validation tests on NWB files')
     examples_nwbs = glob.glob('*.nwb')
 
+    # exclude files downloaded from dandi, validation of those files is handled by dandisets-health-status checks
+    examples_nwbs = [x for x in examples_nwbs if not x.startswith('sub-')]
+
     import pynwb
+    from pynwb.validate import get_cached_namespaces_to_validate
 
     for nwb in examples_nwbs:
         try:
@@ -151,27 +166,36 @@ def validate_nwbs():
             ws = list()
             with warnings.catch_warnings(record=True) as tmp:
                 logging.info("Validating with pynwb.validate method.")
-                with pynwb.NWBHDF5IO(nwb, mode='r') as io:
-                    errors = pynwb.validate(io)
-                    TOTAL += 1
+                is_family_nwb_file = False
+                try:
+                    with pynwb.NWBHDF5IO(nwb, mode='r') as io:
+                        errors = pynwb.validate(io)
+                except OSError as e:
+                    # if the file was created with the family driver, need to use the family driver to open it
+                    if 'family driver should be used' in str(e):
+                        is_family_nwb_file = True
+                        match = re.search(r'(\d+)', nwb)
+                        filename_pattern = nwb[:match.start()] + '%d' + nwb[match.end():]  # infer the filename pattern
+                        memb_size = 1024**2  # note: the memb_size must be the same as the one used to create the file
+                        with h5py.File(filename_pattern, mode='r', driver='family', memb_size=memb_size) as f:
+                            with pynwb.NWBHDF5IO(file=f, manager=None, mode='r') as io:
+                                errors = pynwb.validate(io)
+                    else:
+                        raise e
 
-                    if errors:
-                        FAILURES += 1
-                        ERRORS += 1
-                        for err in errors:
-                            print("Error: %s" % err)
+                TOTAL += 1
 
-                def get_namespaces(nwbfile):
-                    comp = run(["python", "-m", "pynwb.validate",
-                               "--list-namespaces", "--cached-namespace", nwb],
-                               stdout=PIPE, stderr=STDOUT, universal_newlines=True, timeout=30)
+                if errors:
+                    FAILURES += 1
+                    ERRORS += 1
+                    for err in errors:
+                        print("Error: %s" % err)
 
-                    if comp.returncode != 0:
-                        return []
+                # if file was created with family driver, skip pynwb.validate CLI because not yet supported
+                if is_family_nwb_file:
+                    continue
 
-                    return comp.stdout.split()
-
-                namespaces = get_namespaces(nwb)
+                namespaces, _, _ = get_cached_namespaces_to_validate(nwb)
 
                 if len(namespaces) == 0:
                     FAILURES += 1
@@ -179,14 +203,13 @@ def validate_nwbs():
 
                 cmds = []
                 cmds += [["python", "-m", "pynwb.validate", nwb]]
-                cmds += [["python", "-m", "pynwb.validate", "--cached-namespace", nwb]]
                 cmds += [["python", "-m", "pynwb.validate", "--no-cached-namespace", nwb]]
 
                 for ns in namespaces:
                     # for some reason, this logging command is necessary to correctly printing the namespace in the
                     # next logging command
                     logging.info("Namespace found: %s" % ns)
-                    cmds += [["python", "-m", "pynwb.validate", "--cached-namespace", "--ns", ns, nwb]]
+                    cmds += [["python", "-m", "pynwb.validate", "--ns", ns, nwb]]
 
                 for cmd in cmds:
                     logging.info("Validating with \"%s\"." % (" ".join(cmd[:-1])))
@@ -276,6 +299,9 @@ def clean_up_tests():
         "processed_data.nwb",
         "raw_data.nwb",
         "scratch_analysis.nwb",
+        "sub-P11HMH_ses-20061101_ecephys+image.nwb",
+        "test_edit.nwb",
+        "test_edit2.nwb",
         "test_cortical_surface.nwb",
         "test_icephys_file.nwb",
         "test_multicontainerinterface.extensions.yaml",
@@ -287,6 +313,8 @@ def clean_up_tests():
             if os.path.exists(name):
                 os.remove(name)
 
+    shutil.rmtree("zarr_tutorial.nwb.zarr")
+
 
 def main():
     # setup and parse arguments
