@@ -1,4 +1,5 @@
 from hdmf.common import DynamicTableRegion
+from pynwb import NWBFile
 
 from pynwb.ecephys import (
     ElectrodeGroup,
@@ -14,7 +15,7 @@ from pynwb.ecephys import (
 )
 from pynwb.device import Device
 from pynwb.file import ElectrodeTable as get_electrode_table
-from pynwb.testing import NWBH5IOMixin, AcquisitionH5IOMixin, TestCase
+from pynwb.testing import NWBH5IOMixin, AcquisitionH5IOMixin, NWBH5IOFlexMixin, TestCase
 
 
 class TestElectrodeGroupIO(NWBH5IOMixin, TestCase):
@@ -38,27 +39,36 @@ class TestElectrodeGroupIO(NWBH5IOMixin, TestCase):
         return nwbfile.get_electrode_group(self.container.name)
 
 
-class TestElectricalSeriesIO(AcquisitionH5IOMixin, TestCase):
+def setup_electrode_table():
+    table = get_electrode_table()
+    dev1 = Device(name='dev1')
+    group = ElectrodeGroup(
+        name='tetrode1',
+        description='tetrode description',
+        location='tetrode location',
+        device=dev1
+    )
+    for i in range(4):
+        table.add_row(location='CA1', group=group, group_name='tetrode1')
+    return table, group, dev1
 
-    @staticmethod
-    def make_electrode_table(self):
-        """ Make an electrode table, electrode group, and device """
-        self.table = get_electrode_table()
-        self.dev1 = Device(name='dev1')
-        self.group = ElectrodeGroup(name='tetrode1',
-                                    description='tetrode description',
-                                    location='tetrode location',
-                                    device=self.dev1)
-        for i in range(4):
-            self.table.add_row(location='CA1', group=self.group, group_name='tetrode1')
 
-    def setUpContainer(self):
-        """ Return the test ElectricalSeries to read/write """
-        self.make_electrode_table(self)
+class TestElectricalSeriesIO(NWBH5IOFlexMixin, TestCase):
+
+    def getContainerType(self):
+        return "ElectricalSeries"
+
+    def addContainer(self):
+        """ Add the test ElectricalSeries and related objects to the given NWBFile """
+        table, group, dev1 = setup_electrode_table()
+        self.nwbfile.add_device(dev1)
+        self.nwbfile.add_electrode_group(group)
+        self.nwbfile.set_electrode_table(table)
+
         region = DynamicTableRegion(name='electrodes',
                                     data=[0, 2],
                                     description='the first and third electrodes',
-                                    table=self.table)
+                                    table=table)
         data = list(zip(range(10), range(10, 20)))
         timestamps = list(map(lambda x: x/10., range(10)))
         channel_conversion = [1., 2., 3., 4.]
@@ -71,14 +81,11 @@ class TestElectricalSeriesIO(AcquisitionH5IOMixin, TestCase):
             filtering=filtering,
             timestamps=timestamps
         )
-        return es
 
-    def addContainer(self, nwbfile):
-        """ Add the test ElectricalSeries and related objects to the given NWBFile """
-        nwbfile.add_device(self.dev1)
-        nwbfile.add_electrode_group(self.group)
-        nwbfile.set_electrode_table(self.table)
-        nwbfile.add_acquisition(self.container)
+        self.nwbfile.add_acquisition(es)
+
+    def getContainer(self, nwbfile: NWBFile):
+        return nwbfile.acquisition['test_eS']
 
     def test_eg_ref(self):
         """
@@ -92,58 +99,70 @@ class TestElectricalSeriesIO(AcquisitionH5IOMixin, TestCase):
         self.assertIsInstance(row2.iloc[0]['group'], ElectrodeGroup)
 
 
-class MultiElectricalSeriesIOMixin(AcquisitionH5IOMixin):
-    """
-    Mixin class for methods to run a roundtrip test writing an NWB file with multiple ElectricalSeries.
+class TestLFPIO(NWBH5IOFlexMixin, TestCase):
 
-    The abstract method setUpContainer needs to be implemented by classes that include this mixin.
-        def setUpContainer(self):
-            # return a test Container to read/write
-    """
+    def getContainerType(self):
+        return "LFP"
+
+    def addContainer(self):
+        table, group, dev1 = setup_electrode_table()
+        self.nwbfile.add_device(dev1)
+        self.nwbfile.add_electrode_group(group)
+        self.nwbfile.set_electrode_table(table)
 
-    def setUpTwoElectricalSeries(self):
-        """ Return two test ElectricalSeries to read/write """
-        TestElectricalSeriesIO.make_electrode_table(self)
         region1 = DynamicTableRegion(name='electrodes',
                                      data=[0, 2],
                                      description='the first and third electrodes',
-                                     table=self.table)
+                                     table=table)
         region2 = DynamicTableRegion(name='electrodes',
                                      data=[1, 3],
                                      description='the second and fourth electrodes',
-                                     table=self.table)
+                                     table=table)
         data1 = list(zip(range(10), range(10, 20)))
         data2 = list(zip(reversed(range(10)), reversed(range(10, 20))))
         timestamps = list(map(lambda x: x/10., range(10)))
         es1 = ElectricalSeries(name='test_eS1', data=data1, electrodes=region1, timestamps=timestamps)
         es2 = ElectricalSeries(name='test_eS2', data=data2, electrodes=region2, channel_conversion=[4., .4],
                                timestamps=timestamps)
-        return es1, es2
+        lfp = LFP()
+        self.nwbfile.add_acquisition(lfp)
+        lfp.add_electrical_series([es1, es2])
 
-    def addContainer(self, nwbfile):
-        """ Add the test ElectricalSeries and related objects to the given NWBFile """
-        nwbfile.add_device(self.dev1)
-        nwbfile.add_electrode_group(self.group)
-        nwbfile.set_electrode_table(self.table)
-        nwbfile.add_acquisition(self.container)
+    def getContainer(self, nwbfile: NWBFile):
+        return nwbfile.acquisition['LFP']
 
 
-class TestLFPIO(MultiElectricalSeriesIOMixin, TestCase):
+class TestFilteredEphysIO(NWBH5IOFlexMixin, TestCase):
 
-    def setUpContainer(self):
-        """ Return a test LFP to read/write """
-        es = self.setUpTwoElectricalSeries()
-        lfp = LFP(es)
-        return lfp
+    def getContainerType(self):
+        return "FilteredEphys"
 
+    def addContainer(self):
+        table, group, dev1 = setup_electrode_table()
+        self.nwbfile.add_device(dev1)
+        self.nwbfile.add_electrode_group(group)
+        self.nwbfile.set_electrode_table(table)
 
-class TestFilteredEphysIO(MultiElectricalSeriesIOMixin, TestCase):
+        region1 = DynamicTableRegion(name='electrodes',
+                                     data=[0, 2],
+                                     description='the first and third electrodes',
+                                     table=table)
+        region2 = DynamicTableRegion(name='electrodes',
+                                     data=[1, 3],
+                                     description='the second and fourth electrodes',
+                                     table=table)
+        data1 = list(zip(range(10), range(10, 20)))
+        data2 = list(zip(reversed(range(10)), reversed(range(10, 20))))
+        timestamps = list(map(lambda x: x/10., range(10)))
+        es1 = ElectricalSeries(name='test_eS1', data=data1, electrodes=region1, timestamps=timestamps)
+        es2 = ElectricalSeries(name='test_eS2', data=data2, electrodes=region2, channel_conversion=[4., .4],
+                               timestamps=timestamps)
+        fe = FilteredEphys()
+        self.nwbfile.add_acquisition(fe)
+        fe.add_electrical_series([es1, es2])
 
-    def setUpContainer(self):
-        """ Return a test FilteredEphys to read/write """
-        es = self.setUpTwoElectricalSeries()
-        fe = FilteredEphys(es)
-        return fe
+    def getContainer(self, nwbfile: NWBFile):
+        return nwbfile.acquisition['FilteredEphys']
 
 
 class TestClusteringIO(AcquisitionH5IOMixin, TestCase):
@@ -165,28 +184,35 @@ class TestClusteringIO(AcquisitionH5IOMixin, TestCase):
             return super().roundtripExportContainer(cache_spec)
 
 
-class EventWaveformConstructor(AcquisitionH5IOMixin, TestCase):
+class EventWaveformConstructor(NWBH5IOFlexMixin, TestCase):
+
+    def getContainerType(self):
+        return "SpikeEventSeries"
+
+    def addContainer(self):
+        """ Add the test SpikeEventSeries and related objects to the given NWBFile """
+        table, group, dev1 = setup_electrode_table()
+        self.nwbfile.add_device(dev1)
+        self.nwbfile.add_electrode_group(group)
+        self.nwbfile.set_electrode_table(table)
 
-    def setUpContainer(self):
-        """ Return a test EventWaveform to read/write """
-        TestElectricalSeriesIO.make_electrode_table(self)
         region = DynamicTableRegion(name='electrodes',
                                     data=[0, 2],
                                     description='the first and third electrodes',
-                                    table=self.table)
-        sES = SpikeEventSeries(name='test_sES',
-                               data=((1, 1), (2, 2), (3, 3)),
-                               timestamps=[0., 1., 2.],
-                               electrodes=region)
-        ew = EventWaveform(sES)
-        return ew
+                                    table=table)
+        ses = SpikeEventSeries(
+            name='test_sES',
+            data=((1, 1), (2, 2), (3, 3)),
+            timestamps=[0., 1., 2.],
+            electrodes=region
+        )
 
-    def addContainer(self, nwbfile):
-        """ Add the test EventWaveform and related objects to the given NWBFile """
-        nwbfile.add_device(self.dev1)
-        nwbfile.add_electrode_group(self.group)
-        nwbfile.set_electrode_table(self.table)
-        nwbfile.add_acquisition(self.container)
+        ew = EventWaveform()
+        self.nwbfile.add_acquisition(ew)
+        ew.add_spike_event_series(ses)
+
+    def getContainer(self, nwbfile: NWBFile):
+        return nwbfile.acquisition['EventWaveform']
 
 
 class ClusterWaveformsConstructor(AcquisitionH5IOMixin, TestCase):
@@ -220,51 +246,66 @@ class ClusterWaveformsConstructor(AcquisitionH5IOMixin, TestCase):
             return super().roundtripExportContainer(cache_spec)
 
 
-class FeatureExtractionConstructor(AcquisitionH5IOMixin, TestCase):
+class FeatureExtractionConstructor(NWBH5IOFlexMixin, TestCase):
+
+    def getContainerType(self):
+        return "FeatureExtraction"
+
+    def addContainer(self):
+        """ Add the test FeatureExtraction and related objects to the given NWBFile """
+        table, group, dev1 = setup_electrode_table()
+        self.nwbfile.add_device(dev1)
+        self.nwbfile.add_electrode_group(group)
+        self.nwbfile.set_electrode_table(table)
 
-    def setUpContainer(self):
-        """ Return a test FeatureExtraction to read/write """
         event_times = [1.9, 3.5]
-        TestElectricalSeriesIO.make_electrode_table(self)
         region = DynamicTableRegion(name='electrodes',
                                     data=[0, 2],
                                     description='the first and third electrodes',
-                                    table=self.table)
+                                    table=table)
         description = ['desc1', 'desc2', 'desc3']
         features = [[[0., 1., 2.], [3., 4., 5.]], [[6., 7., 8.], [9., 10., 11.]]]
         fe = FeatureExtraction(electrodes=region, description=description, times=event_times, features=features)
-        return fe
 
-    def addContainer(self, nwbfile):
-        """ Add the test FeatureExtraction and related objects to the given NWBFile """
-        nwbfile.add_device(self.dev1)
-        nwbfile.add_electrode_group(self.group)
-        nwbfile.set_electrode_table(self.table)
-        nwbfile.add_acquisition(self.container)
+        self.nwbfile.add_acquisition(fe)
+
+    def getContainer(self, nwbfile: NWBFile):
+        return nwbfile.acquisition['FeatureExtraction']
 
 
-class EventDetectionConstructor(AcquisitionH5IOMixin, TestCase):
+class EventDetectionConstructor(NWBH5IOFlexMixin, TestCase):
+
+    def getContainerType(self):
+        return "EventDetection"
+
+    def addContainer(self):
+        """ Add the test EventDetection and related objects to the given NWBFile """
+        table, group, dev1 = setup_electrode_table()
+        self.nwbfile.add_device(dev1)
+        self.nwbfile.add_electrode_group(group)
+        self.nwbfile.set_electrode_table(table)
 
-    def setUpContainer(self):
-        """ Return a test EventDetection to read/write """
-        TestElectricalSeriesIO.make_electrode_table(self)
         region = DynamicTableRegion(name='electrodes',
                                     data=[0, 2],
                                     description='the first and third electrodes',
-                                    table=self.table)
+                                    table=table)
         data = list(range(10))
         ts = [0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0]
-        self.eS = ElectricalSeries(name='test_eS', data=data, electrodes=region, timestamps=ts)
-        eD = EventDetection(detection_method='detection_method',
-                            source_electricalseries=self.eS,
-                            source_idx=(1, 2, 3),
-                            times=(0.1, 0.2, 0.3))
-        return eD
+        eS = ElectricalSeries(
+            name='test_eS',
+            data=data,
+            electrodes=region,
+            timestamps=ts
+        )
+        eD = EventDetection(
+            detection_method='detection_method',
+            source_electricalseries=eS,
+            source_idx=(1, 2, 3),
+            times=(0.1, 0.2, 0.3)
+        )
 
-    def addContainer(self, nwbfile):
-        """ Add the test EventDetection and related objects to the given NWBFile """
-        nwbfile.add_device(self.dev1)
-        nwbfile.add_electrode_group(self.group)
-        nwbfile.set_electrode_table(self.table)
-        nwbfile.add_acquisition(self.eS)
-        nwbfile.add_acquisition(self.container)
+        self.nwbfile.add_acquisition(eS)
+        self.nwbfile.add_acquisition(eD)
+
+    def getContainer(self, nwbfile: NWBFile):
+        return nwbfile.acquisition['EventDetection']
