@@ -1,19 +1,47 @@
-from copy import deepcopy
 from abc import ABCMeta
+from copy import deepcopy
+import numpy as np
 
 from pynwb.ophys import (
     ImagingPlane,
     OpticalChannel,
     PlaneSegmentation,
     ImageSegmentation,
+    OnePhotonSeries,
     TwoPhotonSeries,
-    RoiResponseSeries
+    RoiResponseSeries,
+    MotionCorrection,
+    CorrectedImageStack,
 )
+from pynwb.base import TimeSeries
 from pynwb.image import ImageSeries
 from pynwb.device import Device
 from pynwb.testing import NWBH5IOMixin, AcquisitionH5IOMixin, TestCase
 
 
+def make_imaging_plane():
+    """ Make an ImagingPlane and related objects """
+    device = Device(name='dev1')
+    optical_channel = OpticalChannel(
+        name='optchan1',
+        description='a fake OpticalChannel',
+        emission_lambda=500.
+    )
+    imaging_plane = ImagingPlane(
+        name='imgpln1',
+        optical_channel=optical_channel,
+        description='a fake ImagingPlane',
+        device=device,
+        excitation_lambda=600.,
+        imaging_rate=300.,
+        indicator='GFP',
+        location='somewhere in the brain',
+        reference_frame='unknown'
+    )
+
+    return device, optical_channel, imaging_plane
+
+
 class TestImagingPlaneIO(NWBH5IOMixin, TestCase):
 
     def setUpContainer(self):
@@ -33,7 +61,11 @@ class TestImagingPlaneIO(NWBH5IOMixin, TestCase):
             imaging_rate=300.,
             indicator='GFP',
             location='somewhere in the brain',
-            reference_frame='unknown'
+            reference_frame='unknown',
+            origin_coords=[10., 20.],
+            origin_coords_unit='millimeters',
+            grid_spacing=[0.001, 0.001],
+            grid_spacing_unit='millimeters',
         )
 
     def addContainer(self, nwbfile):
@@ -46,32 +78,101 @@ class TestImagingPlaneIO(NWBH5IOMixin, TestCase):
         return nwbfile.get_imaging_plane(self.container.name)
 
 
-class TestTwoPhotonSeriesIO(AcquisitionH5IOMixin, TestCase):
+class TestMotionCorrection(NWBH5IOMixin, TestCase):
 
-    def make_imaging_plane(self):
-        """ Make an ImagingPlane and related objects """
-        self.device = Device(name='dev1')
-        self.optical_channel = OpticalChannel(
-            name='optchan1',
-            description='a fake OpticalChannel',
-            emission_lambda=500.
+    def setUpContainer(self):
+        """ Return the test ImagingPlane to read/write """
+
+        self.device, self.optical_channel, self.imaging_plane = make_imaging_plane()
+
+        self.two_photon_series = TwoPhotonSeries(
+            name='TwoPhotonSeries',
+            data=np.ones((1000, 100, 100)),
+            imaging_plane=self.imaging_plane,
+            rate=1.0,
+            unit='normalized amplitude'
         )
-        self.imaging_plane = ImagingPlane(
-            name='imgpln1',
-            optical_channel=self.optical_channel,
-            description='a fake ImagingPlane',
-            device=self.device,
-            excitation_lambda=600.,
-            imaging_rate=300.,
-            indicator='GFP',
-            location='somewhere in the brain',
-            reference_frame='unknown'
+
+        corrected = ImageSeries(
+            name='corrected',
+            data=np.ones((1000, 100, 100)),
+            unit='na',
+            format='raw',
+            starting_time=0.0,
+            rate=1.0
         )
 
+        xy_translation = TimeSeries(
+            name='xy_translation',
+            data=np.ones((1000, 2)),
+            unit='pixels',
+            starting_time=0.0,
+            rate=1.0,
+        )
+
+        corrected_image_stack = CorrectedImageStack(
+            corrected=corrected,
+            original=self.two_photon_series,
+            xy_translation=xy_translation,
+        )
+
+        return MotionCorrection(corrected_image_stacks=[corrected_image_stack])
+
+    def addContainer(self, nwbfile):
+        """ Add the test ImagingPlane and Device to the given NWBFile """
+
+        nwbfile.add_device(self.device)
+        nwbfile.add_imaging_plane(self.imaging_plane)
+        nwbfile.add_acquisition(self.two_photon_series)
+
+        ophys_module = nwbfile.create_processing_module(
+            name='ophys',
+            description='optical physiology processed data'
+        )
+        ophys_module.add(self.container)
+
+    def getContainer(self, nwbfile):
+        """ Return the test ImagingPlane from the given NWBFile """
+        return nwbfile.processing['ophys'].data_interfaces['MotionCorrection']
+
+
+class TestOnePhotonSeriesIO(AcquisitionH5IOMixin, TestCase):
+
+    def setUpContainer(self):
+        """ Return the test OnePhotonSeries to read/write """
+        self.device, self.optical_channel, self.imaging_plane = make_imaging_plane()
+        data = np.ones((10, 2, 2))
+        timestamps = list(map(lambda x: x/10, range(10)))
+        ret = OnePhotonSeries(
+            name='test_2ps',
+            imaging_plane=self.imaging_plane,
+            data=data,
+            unit='image_unit',
+            format='raw',
+            pmt_gain=1.7,
+            scan_line_rate=3.4,
+            exposure_time=123.,
+            binning=2,
+            power=9001.,
+            intensity=5.,
+            timestamps=timestamps,
+            dimension=[2],
+        )
+        return ret
+
+    def addContainer(self, nwbfile):
+        """ Add the test OnePhotonSeries as an acquisition and add Device and ImagingPlane to the given NWBFile """
+        nwbfile.add_device(self.device)
+        nwbfile.add_imaging_plane(self.imaging_plane)
+        nwbfile.add_acquisition(self.container)
+
+
+class TestTwoPhotonSeriesIO(AcquisitionH5IOMixin, TestCase):
+
     def setUpContainer(self):
         """ Return the test TwoPhotonSeries to read/write """
-        self.make_imaging_plane()
-        data = [[[1., 1.] * 2] * 2]
+        self.device, self.optical_channel, self.imaging_plane = make_imaging_plane()
+        data = np.ones((10, 2, 2))
         timestamps = list(map(lambda x: x/10, range(10)))
         fov = [2.0, 2.0, 5.0]
         ret = TwoPhotonSeries(
@@ -106,9 +207,14 @@ class TestPlaneSegmentationIO(NWBH5IOMixin, TestCase):
                     (7, 8, 2.0), (9, 10, 2.)]
 
         ts = [0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9]
-        self.image_series = ImageSeries(name='test_iS', dimension=[2],
-                                        external_file=['images.tiff'],
-                                        starting_frame=[1, 2, 3], format='tiff', timestamps=ts)
+        self.image_series = ImageSeries(
+            name='test_iS',
+            dimension=[2],
+            external_file=['images.tiff'],
+            starting_frame=[0],
+            format='external',
+            timestamps=ts
+        )
 
         self.device = Device(name='dev1')
         self.optical_channel = OpticalChannel(
@@ -170,9 +276,14 @@ class MaskIO(TestPlaneSegmentationIO, metaclass=ABCMeta):
     def buildPlaneSegmentationNoRois(self):
         """ Return an PlaneSegmentation and set related objects """
         ts = [0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9]
-        self.image_series = ImageSeries(name='test_iS', dimension=[2],
-                                        external_file=['images.tiff'],
-                                        starting_frame=[1, 2, 3], format='tiff', timestamps=ts)
+        self.image_series = ImageSeries(
+            name='test_iS',
+            dimension=[2],
+            external_file=['images.tiff'],
+            starting_frame=[0],
+            format='external',
+            timestamps=ts
+        )
         self.device = Device(name='dev1')
         self.optical_channel = OpticalChannel(
             name='test_optical_channel',
@@ -253,3 +364,44 @@ class TestRoiResponseSeriesIO(AcquisitionH5IOMixin, TestCase):
                                                description='a plain module for testing')
         mod.add(img_seg)
         super().addContainer(nwbfile)
+
+
+class TestCorrectedImageStackIO(AcquisitionH5IOMixin, TestCase):
+
+    def setUpContainer(self):
+        """Return the test CorrectedImageStack to read/write."""
+        timestamps = [1., 2.]
+
+        corrected_is = ImageSeries(
+            name='corrected',
+            unit='unit',
+            external_file=['external_file'],
+            starting_frame=[0],
+            format='external',
+            timestamps=timestamps
+        )
+        self.original_is = ImageSeries(
+            name='original_is',
+            unit='unit',
+            external_file=['external_file'],
+            starting_frame=[0],
+            format='external',
+            timestamps=timestamps
+        )
+        tstamps = [1., 2., 3.]
+        ts = TimeSeries(
+            name='xy_translation',
+            data=list(range(len(tstamps))),
+            unit='unit',
+            timestamps=tstamps
+        )
+        return CorrectedImageStack(
+            corrected=corrected_is,
+            original=self.original_is,
+            xy_translation=ts
+        )
+
+    def addContainer(self, nwbfile):
+        """Add the test CorrectedImageStack and the original ImageSeries in acquisition."""
+        nwbfile.add_acquisition(self.original_is)
+        super().addContainer(nwbfile)
