@@ -10,7 +10,7 @@ from hdmf.utils import get_docval, docval, popargs
 from pynwb import get_type_map, TimeSeries, NWBFile, register_class, load_namespaces, get_class
 from pynwb.spec import NWBNamespaceBuilder, NWBGroupSpec, NWBAttributeSpec, NWBDatasetSpec
 from pynwb.file import LabMetaData
-from pynwb.testing import TestCase
+from pynwb.testing import TestCase, remove_test_file
 
 
 def id_generator(N=10):
@@ -31,7 +31,7 @@ class TestExtension(TestCase):
     def tearDown(self):
         for f in (self.ext_source, self.ns_path):
             path = os.path.join(self.tempdir, f)
-            os.remove(path)
+            remove_test_file(path)
 
     def test_export(self):
         ns_builder = NWBNamespaceBuilder('Extension for use in my Lab', self.prefix, version='0.1.0')
@@ -49,7 +49,7 @@ class TestExtension(TestCase):
     def test_get_class(self):
         self.test_export()
         type_map = get_type_map(extensions=os.path.join(self.tempdir, self.ns_path))
-        type_map.get_container_cls(self.prefix, 'TetrodeSeries')
+        type_map.get_dt_container_cls('TetrodeSeries', self.prefix)
 
     def test_load_namespace_with_reftype_attribute(self):
         ns_builder = NWBNamespaceBuilder('Extension for use in my Lab', self.prefix, version='0.1.0')
@@ -74,7 +74,7 @@ class TestExtension(TestCase):
         ns_builder.add_spec(self.ext_source, test_ds_ext)
         ns_builder.export(self.ns_path, outdir=self.tempdir)
         type_map = get_type_map(extensions=os.path.join(self.tempdir, self.ns_path))
-        my_new_type = type_map.get_container_cls(self.prefix, 'my_new_type')
+        my_new_type = type_map.get_dt_container_cls('my_new_type', self.prefix)
         docval = None
         for tmp in get_docval(my_new_type.__init__):
             if tmp['name'] == 'target_ds':
@@ -105,7 +105,7 @@ class TestExtension(TestCase):
                     {'name': 'test_attr', 'type': float, 'doc': 'test attribute'})
             def __init__(self, **kwargs):
                 test_attr = popargs('test_attr', kwargs)
-                super(MyTestMetaData, self).__init__(**kwargs)
+                super().__init__(**kwargs)
                 self.test_attr = test_attr
 
         nwbfile = NWBFile("a file with header data", "NB123A",  datetime(2017, 5, 1, 12, 0, 0, tzinfo=tzlocal()))
@@ -150,7 +150,7 @@ class TestCatchDupNS(TestCase):
                  self.ns_path2)
         for f in files:
             path = os.path.join(self.tempdir, f)
-            os.remove(path)
+            remove_test_file(path)
 
     def test_catch_dup_name(self):
         ns_builder1 = NWBNamespaceBuilder('Extension for us in my Lab', "pynwb_test_extension1", version='0.1.0')
@@ -168,30 +168,4 @@ class TestCatchDupNS(TestCase):
         ns_builder2.add_spec(self.ext_source2, ext2)
         ns_builder2.export(self.ns_path2, outdir=self.tempdir)
         type_map = get_type_map(extensions=os.path.join(self.tempdir, self.ns_path1))
-        with self.assertWarnsRegex(UserWarning, r"ignoring namespace '\S+' because it already exists"):
-            type_map.load_namespaces(os.path.join(self.tempdir, self.ns_path2))
-
-
-class TestCatchDuplicateSpec(TestCase):
-
-    def setUp(self):
-        self.prefix = id_generator()
-        self.ext_source = '%s_extension3.yaml' % self.prefix
-
-    def tearDown(self):
-        pass
-
-    def test_catch_duplicate_spec(self):
-        spec1 = NWBGroupSpec("This is my new group 1",
-                             "Group1",
-                             neurodata_type_inc="NWBDataInterface",
-                             neurodata_type_def="Group1")
-        spec2 = NWBGroupSpec("This is my new group 2",
-                             "Group2",
-                             groups=[spec1],
-                             neurodata_type_inc="NWBDataInterface",
-                             neurodata_type_def="Group2")
-        ns_builder = NWBNamespaceBuilder("Example namespace", "pynwb_test_ext", version='0.1.0')
-        ns_builder.add_spec(self.ext_source, spec1)
-        with self.assertRaises(ValueError):
-            ns_builder.add_spec(self.ext_source, spec2)
+        type_map.load_namespaces(os.path.join(self.tempdir, self.ns_path2))
