@@ -7,14 +7,25 @@ class OptogeneticSeriesConstructor(TestCase):
 
     def test_init(self):
         device = Device('name')
-        oS = OptogeneticStimulusSite('site1', device, 'description', 300., 'location')
+        oS = OptogeneticStimulusSite(
+            name='site1',
+            device=device,
+            description='description',
+            excitation_lambda=300.,
+            location='location'
+        )
         self.assertEqual(oS.name, 'site1')
         self.assertEqual(oS.device, device)
         self.assertEqual(oS.description, 'description')
         self.assertEqual(oS.excitation_lambda, 300.)
         self.assertEqual(oS.location, 'location')
 
-        iS = OptogeneticSeries('test_iS', list(), oS, timestamps=list())
+        iS = OptogeneticSeries(
+            name='test_iS',
+            data=[1, 2, 3],
+            site=oS,
+            timestamps=[0.1, 0.2, 0.3]
+        )
         self.assertEqual(iS.name, 'test_iS')
         self.assertEqual(iS.unit, 'watts')
         self.assertEqual(iS.site, oS)
